@@ -117,7 +117,7 @@ class App:
         #     scope["PATH_INFO"] = path_info[len("/static"):]
         #     return self.whitenoise(environ, start_response)
 
-        return self.middleware(scope, recieve, send)
+        await self.middleware(scope, recieve, send)
 
     def handle_request(self, request):
         handler, kwargs = self.find_handler(request_path=request.url.path)
@@ -136,7 +136,7 @@ class App:
 
         except Exception as e:
             error = traceback.format_exc()
-            self.exception_handler.handle_error(request, error)
+            return self.exception_handler.handle_error(error)
 
         return response
 
