@@ -1,9 +1,9 @@
 from arc.middleware import Middleware
 from arc.errors import AppException
 import os
-import pathlib
 from jinja2 import Environment, FileSystemLoader
 from jinja2.loaders import FileSystemLoader
+from starlette.responses import PlainTextResponse
 
 
 class DefaultMiddleware(Middleware):
@@ -22,13 +22,15 @@ class DefaultExceptionHandler:
         self.errors_env = Environment(
             loader=FileSystemLoader(os.path.join(self.dir_path, "selfpages")))
 
-    def handle_error(self, request, response, error):
-        response.status_code = 500
-        response.body = self.errors_env.get_template(
-            "error-500.html").render({"error": error}).encode()
+    def handle_error(self, error):
+        return PlainTextResponse("ERROR: \n", error)
+        
+        
+        # response.body = self.errors_env.get_template(
+        #     "error-500.html").render({"error": error}).encode()
 
     def handle_404(self, response):
-        response.status_code = 404
+        return PlainTextResponse("ERROR 404")
 
-        response.body = self.errors_env.get_template(
-            "error-404.html").render().encode()
+        # response.body = self.errors_env.get_template(
+        #     "error-404.html").render().encode()
